@@ -8,7 +8,7 @@ from checkov.common.util.type_forcers import force_float
 class GreaterThanOrEqualAttributeSolver(BaseAttributeSolver):
     operator = Operators.GREATER_THAN_OR_EQUAL  # noqa: CCE003  # a static attribute
 
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
 
         vertex_attr = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
         # if this value contains an underendered variable, then we cannot evaluate the check,
