@@ -7,7 +7,7 @@ from checkov.common.checks_infra.solvers.attribute_solvers.base_attribute_solver
 class IsTrueAttributeSolver(BaseAttributeSolver):
     operator = Operators.IS_TRUE  # noqa: CCE003  # a static attribute
 
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
         attr = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
         if attr is None:
             return False
