@@ -7,7 +7,7 @@ from .equals_attribute_solver import EqualsAttributeSolver
 class NotEqualsAttributeSolver(EqualsAttributeSolver):
     operator = Operators.NOT_EQUALS  # noqa: CCE003  # a static attribute
 
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
         attr_val = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
         # if this value contains an underendered variable, then we cannot evaluate the check,
         # so return True (since we cannot return UNKNOWN)
