@@ -7,7 +7,7 @@ from checkov.common.checks_infra.solvers.attribute_solvers.base_attribute_solver
 class WithinAttributeSolver(BaseAttributeSolver):
     operator = Operators.WITHIN  # noqa: CCE003  # a static attribute
 
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
         attr = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
         # if this value contains an underendered variable, then we cannot evaluate the check,
         # so return True (since we cannot return UNKNOWN)
