@@ -26,7 +26,7 @@ class Runner(JsonRunner):
         files: list[str] | None = None,
         runner_filter: RunnerFilter | None = None,
         collect_skip_comments: bool = True
-    ) -> Report:
+    ) -> Report | list[Report]:
         runner_filter = runner_filter or RunnerFilter()
         if not runner_filter.show_progress_bar:
             self.pbar.turn_off_progress_bar()
@@ -36,7 +36,7 @@ class Runner(JsonRunner):
         report = super().run(root_folder=self.github.github_conf_dir_path, external_checks_dir=external_checks_dir,
                              files=files,
                              runner_filter=runner_filter, collect_skip_comments=collect_skip_comments)
-        JsonRunner._change_files_path_to_relative(report)
+        JsonRunner._change_files_path_to_relative(report)  # type:ignore[arg-type]  # report can only be of type Report, not a list
         return report
 
     def prepare_data(self) -> None:
