@@ -2,6 +2,9 @@ from checkov.common.checks.base_check_registry import BaseCheckRegistry
 
 
 class Registry(BaseCheckRegistry):
+    def __init__(self, report_type: str):
+        super().__init__(report_type)
+
     def extract_entity_details(self, entity):
         kind = entity["kind"]
         conf = entity
@@ -17,7 +20,7 @@ class Registry(BaseCheckRegistry):
                 if check.id in [x['id'] for x in skipped_checks]:
                     skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
 
-            if self._should_run_scan(check, entity_configuration, runner_filter):
+            if self._should_run_scan(check, entity_configuration, runner_filter, self.report_type):
                 self.logger.debug("Running check: {} on file {}".format(check.name, scanned_file))
 
                 result = check.run(scanned_file=scanned_file, entity_configuration=entity_configuration,
@@ -26,7 +29,7 @@ class Registry(BaseCheckRegistry):
         return results
 
     @staticmethod
-    def _should_run_scan(check, entity_configuration, runner_filter):
+    def _should_run_scan(check, entity_configuration, runner_filter, report_type):
         check_id_allowlist = runner_filter.checks
         check_id_denylist = runner_filter.skip_checks
         if check_id_allowlist or runner_filter.check_threshold:
@@ -46,7 +49,7 @@ class Registry(BaseCheckRegistry):
                     if "default" in allowed_namespaces:
                         run_check = True
             else:
-                if runner_filter.should_run_check(check=check):
+                if runner_filter.should_run_check(check=check, report_type=report_type):
                     if allowed_namespaces:
                         # Check if namespace in allowed namespaces
                         if "metadata" in entity_configuration and "namespace" in entity_configuration["metadata"]:
@@ -63,7 +66,7 @@ class Registry(BaseCheckRegistry):
                         run_check = True
             if run_check:
                 return True
-        elif check_id_denylist or runner_filter.skip_check_threshold:
+        elif check_id_denylist or runner_filter.skip_check_threshold or runner_filter.use_enforcement_rules:
             namespace_skip = False
             if "metadata" in entity_configuration and "namespace" in entity_configuration["metadata"]:
                 if entity_configuration["metadata"]["namespace"] in check_id_denylist:
@@ -74,7 +77,7 @@ class Registry(BaseCheckRegistry):
             else:
                 if "default" in check_id_denylist:
                     namespace_skip = True
-            if runner_filter.should_run_check(check=check) and not namespace_skip:
+            if runner_filter.should_run_check(check=check, report_type=report_type) and not namespace_skip:
                 return True
         else:
             return True
