@@ -1,9 +1,22 @@
+from dataclasses import dataclass
 from typing import Dict, Any
 
 from checkov.common.graph.graph_builder.graph_components.blocks import Block
 from checkov.common.graph.graph_builder.graph_components.block_types import BlockType
 
 
+@dataclass
+class KubernetesSelector:
+    match_labels: Dict[str, Any]
+
+
+@dataclass
+class KubernetesBlockMetadata:
+    selector: KubernetesSelector
+    labels: Dict[str, Any]
+    name: str
+
+
 class KubernetesBlock(Block):
     def __init__(
             self,
@@ -12,5 +25,8 @@ class KubernetesBlock(Block):
             config: Dict[str, Any],
             path: str,
             attributes: Dict[str, Any],
+            metadata: KubernetesBlockMetadata
     ) -> None:
         super().__init__(block_name, config, path, BlockType.RESOURCE, attributes, block_name, 'Kubernetes')
+        self.metadata = metadata
+        self.resource_type = resource_type
