@@ -21,6 +21,8 @@ class ReadinessProbe(BaseResourceValueCheck):
         spec = conf.get('spec', [None])[0]
         if isinstance(spec, dict) and spec:
             containers = spec.get("container")
+            if containers is None:
+                return CheckResult.UNKNOWN
             for idx, container in enumerate(containers):
                 if not isinstance(container, dict):
                     return CheckResult.UNKNOWN
