@@ -215,6 +215,14 @@ class Runner(ImageReferencerMixin, BaseRunner):
                     connected_node_data = self.get_connected_node(entity, root_folder)
                     if platform.system() == "Windows":
                         root_folder = os.path.split(full_file_path)[0]
+                    resource_id = ".".join(entity_context['definition_path'])
+                    resource = resource_id
+                    module_dependency = entity.get("module_dependency_")
+                    module_dependency_num = entity.get("module_dependency_num_")
+                    if module_dependency and module_dependency_num:
+                        referrer_id = self._find_id_for_referrer(f'{full_file_path}[{module_dependency}#{module_dependency_num}]')
+                        if referrer_id:
+                            resource = f'{referrer_id}.{resource_id}'
                     record = Record(
                         check_id=check.id,
                         bc_check_id=check.bc_id,
@@ -224,7 +232,7 @@ class Runner(ImageReferencerMixin, BaseRunner):
                         file_path=f"/{os.path.relpath(full_file_path, root_folder)}",
                         file_line_range=[entity_context.get('start_line'),
                                          entity_context.get('end_line')],
-                        resource=".".join(entity_context['definition_path']),
+                        resource=resource,
                         entity_tags=entity.get('tags', {}),
                         evaluations=entity_evaluations,
                         check_class=check.__class__.__module__,
@@ -236,7 +244,7 @@ class Runner(ImageReferencerMixin, BaseRunner):
                         connected_node=connected_node_data
                     )
                     if self.breadcrumbs:
-                        breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
+                        breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(resource_id)
                         if breadcrumb:
                             record = GraphRecord(record, breadcrumb)
                     record.set_guideline(check.guideline)
@@ -521,7 +529,10 @@ class Runner(ImageReferencerMixin, BaseRunner):
                 __cache_file_content(file_name=file, file_modules=file_content["module"])
 
     def extract_images(
-        self, graph_connector: DiGraph | None = None, definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] | None = None
+        self,
+        graph_connector: DiGraph | None = None,
+        definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] | None = None,
+        definitions_raw: dict[str, list[tuple[int, str]]] | None = None
     ) -> list[Image]:
         if not graph_connector:
             # should not happen
